@@ -10,9 +10,9 @@ use Perinci::To::POD;
 use Sub::Identify qw(sub_fullname);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-13'; # DATE
+our $DATE = '2022-06-23'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Rinci'; # DIST
-our $VERSION = '0.781'; # VERSION
+our $VERSION = '0.782'; # VERSION
 
 our $pa = Perinci::Access::Perl->new;
 
@@ -27,7 +27,7 @@ has exclude_files => (
 );
 
 sub _process_module {
-    require Require::Hook::DzilBuild;
+    require Require::Hook::Source::DzilBuild;
 
     my ($self, $document, $input) = @_;
 
@@ -39,7 +39,7 @@ sub _process_module {
     my $package = $1;
     $package =~ s!/!::!g;
 
-    local @INC = (Require::Hook::DzilBuild->new(zilla => $input->{zilla}, debug=>1), @INC);
+    local @INC = (Require::Hook::Source::DzilBuild->new(zilla => $input->{zilla}, debug=>1), @INC);
 
     # force reload to get the recent version of module
     (my $package_pm = "$package.pm") =~ s!::!/!g;
@@ -132,7 +132,7 @@ sub _process_script {
     require File::Temp;
     require Perinci::CmdLine::POD;
     require Perinci::CmdLine::Util;
-    #require Require::Hook::DzilBuild; # script is dumped in a different process, so doesn't work here
+    #require Require::Hook::Source::DzilBuild; # script is dumped in a different process, so doesn't work here
 
     my ($self, $document, $input) = @_;
     # dump to temporary file first because the file might not be an ondisk file
@@ -249,7 +249,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.781 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2022-06-13.
+This document describes version 0.782 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2022-06-23.
 
 =head1 SYNOPSIS
 
